@@ -2,4 +2,4 @@ from .binary_uuid import BinaryUUID
 from .abstract_model import BaseModal
 from .func_date import convert_date_to_timestamp, get_timestamp_now
 from .prepare_json_response import prepare_json_response
-from .generic_pagination import generic_pagination
+from .generic_pagination import PaginationSchema
