@@ -6,10 +6,12 @@ class PaginationSchema(ma.SQLAlchemyAutoSchema):
     # global schema_object
     schema_object = None
     many = False
+    ordered = False
 
-    def __init__(self,  app, schema_object, many=False):
+    def __init__(self,  app, schema_object, many=False, ordered=False):
         self.schema_object = schema_object
         self.many = many
+        self.ordered = ordered
         ma.init_app(app)
 
 
